@@ -59,15 +59,17 @@ class JDBCStoreHelper(DataStoreHelper):
 
         self.__preload_existing_series()
 
-    def get_series_table(self, series: typing.Tuple[datetime, datetime, str]) -> Table:
+    def get_series_table(self, series: typing.Tuple[datetime, datetime, str], alias: str = None) -> Table:
         freq = series[2].strip().lower()
 
         if freq not in self.frequency_to_tbl:
             raise RuntimeError(
                 f'Frequency `{freq}` is not found within cache. Verify the series exist in `{self.series_schema} on `{self.engine.url}`.')
 
-        t_name = f't_{freq}_{str(int(datetime.utcnow().timestamp()))}_{str(random.randint(1, 100000))}'
-        return self.frequency_to_tbl[freq].alias(t_name)
+        if alias is None:
+            alias = f't_{freq}_{str(int(datetime.utcnow().timestamp()))}_{str(random.randint(1, 100000))}'
+
+        return self.frequency_to_tbl[freq].alias(alias)
 
     def __preload_existing_series(self):
         for s in DEFAULT_SERIES:
@@ -163,6 +165,9 @@ def __add_effective_dating_constraint(blocks: ReadRequestBuildingBlocks, res: Re
         blocks.constraints.append(
             blocks.effective_dating_table.c.dt.op(op2)(datetime_to_date_string(blocks.effective_end_dt))
         )
+
+        blocks.columns.append(blocks.effective_dating_table.c.dt.label('effective_dt'))
+
     else:
         blocks.constraints.append(
             a.c.effective_start_dt
@@ -200,6 +205,8 @@ def __add_valid_dating_constraint(blocks: ReadRequestBuildingBlocks, res: Resolv
             blocks.valid_dating_table.c.dt.op(op2)(datetime_to_date_string(blocks.valid_end_dt))
         )
 
+        blocks.columns.append(blocks.valid_dating_table.c.dt.label('valid_dt'))
+
 
 def __populate_building_blocks_dating(request_field: str, start_field: str, end_field: str, dating_tbl_field: str, semantics_field: str,
                                       helper: DataStoreHelper, blocks: ReadRequestBuildingBlocks, r: ReadRequest):
@@ -219,12 +226,11 @@ def __populate_building_blocks_dating(request_field: str, start_field: str, end_
             setattr(blocks, end_field, end)
 
         elif len(dating) == 3:
-
-            setattr(blocks, dating_tbl_field, helper.get_series_table(dating))
+            setattr(blocks, dating_tbl_field, helper.get_series_table(dating, alias=request_field))
             setattr(blocks, start_field, dating[0])
             setattr(blocks, end_field, dating[1])
         elif len(dating) == 4:
-            setattr(blocks, dating_tbl_field, helper.get_series_table(dating))
+            setattr(blocks, dating_tbl_field, helper.get_series_table(dating, alias=request_field))
             setattr(blocks, start_field, dating[0])
             setattr(blocks, end_field, dating[1])
             setattr(blocks, semantics_field, dating[3])
@@ -334,7 +340,7 @@ def __build_read_query(
             if r.partition_column_name not in a.c:
                 raise RuntimeError('Could not identify partition column.')
 
-            index_expression = a.c.knowledge_hash % r.partition_num
+            index_expression = func.abs(a.c.knowledge_hash % r.partition_num)
             blocks.columns.append(index_expression.label('partition'))
 
         if r.additional_constraints is not None:
